import React, { useState } from 'react';
import RecordButton from '../components/RecordButton';
import TranscriptionField from '../components/TranscriptionField';
import CopyButton from '../components/CopyButton';
import AudioRecorder from '../components/AudioRecorder';
import StatusIndicator from '../components/StatusIndicator';
import { transcribeAudio } from '../services/whisperApi';
import logo from '../logo.png';
import './TranscriptionPage.css';

const TranscriptionPage = () => {
  const [isRecording, setIsRecording] = useState(false);
  const [transcription, setTranscription] = useState('');
  const [status, setStatus] = useState('');
  
  const { startRecording, stopRecording, error } = AudioRecorder({
    onRecordingComplete: async (audioBlob) => {
      try {
        setStatus('TRANSCRIBING');
        const text = await transcribeAudio(audioBlob);
        setTranscription(text);
        setStatus('');
      } catch (err) {
        console.error('Transcription error:', err);
        setStatus('ERROR');
      }
    }
  });

  const handleRecordClick = async () => {
    if (!isRecording) {
      const started = await startRecording();
      if (started) {
        setIsRecording(true);
        setStatus('RECORDING');
      }
    } else {
      const stopped = stopRecording();
      if (stopped) {
        setIsRecording(false);
      }
    }
  };

  const handleCopy = () => {
    navigator.clipboard.writeText(transcription);
  };

  return (
    <div className="transcription-page">
      <img src={logo} alt="Voice 2 Clip Logo" className="logo" />
      
      <RecordButton 
        isRecording={isRecording}
        onClick={handleRecordClick}
      />

      {status && <StatusIndicator status={status} />}
      {error && <div className="error-message">{error}</div>}

      <TranscriptionField transcription={transcription} />

      <CopyButton 
        onClick={handleCopy}
        disabled={!transcription}
      />
    </div>
  );
};

export default TranscriptionPage;

