import React, { useState } from 'react';
import { useLocation, useNavigate } from 'react-router-dom';
import CopyButton from '../components/CopyButton';
import TranscriptionField from '../components/TranscriptionField';
import './TranscriptionResultsPage.css';

const TranscriptionResultsPage = () => {
  const location = useLocation();
  const navigate = useNavigate();
  const [copied, setCopied] = useState(false);
  
  const transcription = location.state?.transcription || '';

  const handleCopy = () => {
    navigator.clipboard.writeText(transcription);
    setCopied(true);
    setTimeout(() => setCopied(false), 2000);
  };

  const handleNewRecording = () => {
    navigate('/');
  };

  return (
    <div className="results-page">
      <h2>Your Transcription</h2>
      
      <TranscriptionField transcription={transcription} />
      
      <div className="actions">
        <CopyButton 
          onClick={handleCopy}
          disabled={!transcription}
        />
        {copied && <span className="copy-notification">Copied!</span>}
      </div>

      <button 
        className="new-recording-button"
        onClick={handleNewRecording}
      >
        New Recording
      </button>
    </div>
  );
};

export default TranscriptionResultsPage;

